@@ -9,7 +9,7 @@ import (
 //go:embed scripts/omp.bash
 var bashInit string
 
-func (f Feature) Bash() Code {
+func (f Features) Bash() Code {
 	switch f {
 	case CursorPositioning:
 		return unixCursorPositioning
@@ -49,7 +49,7 @@ bleopt prompt_ps1_final='$(
         --shell-version="$BASH_VERSION" \
         --escape=false
 )'`
-	case PromptMark, PoshGit, Azure, LineError, Jobs, Tooltips, Async:
+	case PromptMark, PoshGit, Azure, LineError, Jobs, Tooltips, Async, Streaming, KeyHandlers:
 		fallthrough
 	default:
 		return ""
