@@ -1,4 +1,4 @@
-module.exports = {
+export default {
   docs: [
     {
       type: "category",
@@ -202,10 +202,11 @@ module.exports = {
           items: [
             "segments/web/brewfather",
             "segments/web/carbonintensity",
-            "segments/web/ipify",
             "segments/web/http",
+            "segments/web/ipify",
             "segments/web/nba",
             "segments/web/owm",
+            "segments/web/todoist",
             "segments/web/wakatime",
           ]
         },
@@ -233,6 +234,14 @@ module.exports = {
         "advanced/mcp-server",
       ],
     },
+    {
+      type: "category",
+      label: "🧪 Experimental",
+      collapsed: true,
+      items: [
+        "experimental/streaming",
+      ],
+    },
     "faq",
     "migrating",
     "contributors",
